FakeTurn class final
One scripted turn: either an answer or a failure.
- Annotations
-
- @immutable
Constructors
- FakeTurn.answer(ChatResponse response)
-
Answers with
response.const -
FakeTurn.chunks(List<
ChatChunk> chunks) -
Answers by emitting
chunksverbatim when streamed.const - FakeTurn.failure(AgenticException error)
-
Fails with
error.const
Properties
-
chunks
→ List<
ChatChunk> ? -
Explicit chunks, when this turn scripts a stream.
final
- error → AgenticException?
-
The failure, when this turn fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → ChatResponse?
-
The answer, when this turn succeeds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited